# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/sagemaker/training_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/sagemaker/training_job.proto',
  package='flyteidl.plugins.sagemaker',
  syntax='proto3',
  serialized_options=_b('Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n-flyteidl/plugins/sagemaker/training_job.proto\x12\x1a\x66lyteidl.plugins.sagemaker\"\xc3\x02\n\x16\x41lgorithmSpecification\x12\x39\n\ninput_mode\x18\x01 \x01(\x0e\x32%.flyteidl.plugins.sagemaker.InputMode\x12\x41\n\x0e\x61lgorithm_name\x18\x02 \x01(\x0e\x32).flyteidl.plugins.sagemaker.AlgorithmName\x12\x19\n\x11\x61lgorithm_version\x18\x03 \x01(\t\x12_\n\x12metric_definitions\x18\x04 \x03(\x0b\x32\x43.flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition\x1a/\n\x10MetricDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05regex\x18\x02 \x01(\t\"]\n\x11TrainingJobConfig\x12\x16\n\x0einstance_count\x18\x01 \x01(\x03\x12\x15\n\rinstance_type\x18\x02 \x01(\t\x12\x19\n\x11volume_size_in_gb\x18\x03 \x01(\x03\"U\n\x11StoppingCondition\x12\x1e\n\x16max_runtime_in_seconds\x18\x01 \x01(\x03\x12 \n\x18max_wait_time_in_seconds\x18\x02 \x01(\x03\"\xc5\x01\n\x0bTrainingJob\x12S\n\x17\x61lgorithm_specification\x18\x01 \x01(\x0b\x32\x32.flyteidl.plugins.sagemaker.AlgorithmSpecification\x12J\n\x13training_job_config\x18\x02 \x01(\x0b\x32-.flyteidl.plugins.sagemaker.TrainingJobConfig\x12\x15\n\rinterruptible\x18\x04 \x01(\x08*\x1f\n\tInputMode\x12\x08\n\x04\x46ILE\x10\x00\x12\x08\n\x04PIPE\x10\x01*(\n\rAlgorithmName\x12\n\n\x06\x43USTOM\x10\x00\x12\x0b\n\x07XGBOOST\x10\x01\x42\x35Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)

_INPUTMODE = _descriptor.EnumDescriptor(
  name='InputMode',
  full_name='flyteidl.plugins.sagemaker.InputMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=785,
  serialized_end=816,
)
_sym_db.RegisterEnumDescriptor(_INPUTMODE)

InputMode = enum_type_wrapper.EnumTypeWrapper(_INPUTMODE)
_ALGORITHMNAME = _descriptor.EnumDescriptor(
  name='AlgorithmName',
  full_name='flyteidl.plugins.sagemaker.AlgorithmName',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CUSTOM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XGBOOST', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=818,
  serialized_end=858,
)
_sym_db.RegisterEnumDescriptor(_ALGORITHMNAME)

AlgorithmName = enum_type_wrapper.EnumTypeWrapper(_ALGORITHMNAME)
FILE = 0
PIPE = 1
CUSTOM = 0
XGBOOST = 1



_ALGORITHMSPECIFICATION_METRICDEFINITION = _descriptor.Descriptor(
  name='MetricDefinition',
  full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regex', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition.regex', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=401,
)

_ALGORITHMSPECIFICATION = _descriptor.Descriptor(
  name='AlgorithmSpecification',
  full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mode', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.input_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm_name', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.algorithm_name', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm_version', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.algorithm_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metric_definitions', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.metric_definitions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ALGORITHMSPECIFICATION_METRICDEFINITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=401,
)


_TRAININGJOBCONFIG = _descriptor.Descriptor(
  name='TrainingJobConfig',
  full_name='flyteidl.plugins.sagemaker.TrainingJobConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_count', full_name='flyteidl.plugins.sagemaker.TrainingJobConfig.instance_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='flyteidl.plugins.sagemaker.TrainingJobConfig.instance_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_size_in_gb', full_name='flyteidl.plugins.sagemaker.TrainingJobConfig.volume_size_in_gb', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=496,
)


_STOPPINGCONDITION = _descriptor.Descriptor(
  name='StoppingCondition',
  full_name='flyteidl.plugins.sagemaker.StoppingCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_runtime_in_seconds', full_name='flyteidl.plugins.sagemaker.StoppingCondition.max_runtime_in_seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_wait_time_in_seconds', full_name='flyteidl.plugins.sagemaker.StoppingCondition.max_wait_time_in_seconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=583,
)


_TRAININGJOB = _descriptor.Descriptor(
  name='TrainingJob',
  full_name='flyteidl.plugins.sagemaker.TrainingJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm_specification', full_name='flyteidl.plugins.sagemaker.TrainingJob.algorithm_specification', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='training_job_config', full_name='flyteidl.plugins.sagemaker.TrainingJob.training_job_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interruptible', full_name='flyteidl.plugins.sagemaker.TrainingJob.interruptible', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=783,
)

_ALGORITHMSPECIFICATION_METRICDEFINITION.containing_type = _ALGORITHMSPECIFICATION
_ALGORITHMSPECIFICATION.fields_by_name['input_mode'].enum_type = _INPUTMODE
_ALGORITHMSPECIFICATION.fields_by_name['algorithm_name'].enum_type = _ALGORITHMNAME
_ALGORITHMSPECIFICATION.fields_by_name['metric_definitions'].message_type = _ALGORITHMSPECIFICATION_METRICDEFINITION
_TRAININGJOB.fields_by_name['algorithm_specification'].message_type = _ALGORITHMSPECIFICATION
_TRAININGJOB.fields_by_name['training_job_config'].message_type = _TRAININGJOBCONFIG
DESCRIPTOR.message_types_by_name['AlgorithmSpecification'] = _ALGORITHMSPECIFICATION
DESCRIPTOR.message_types_by_name['TrainingJobConfig'] = _TRAININGJOBCONFIG
DESCRIPTOR.message_types_by_name['StoppingCondition'] = _STOPPINGCONDITION
DESCRIPTOR.message_types_by_name['TrainingJob'] = _TRAININGJOB
DESCRIPTOR.enum_types_by_name['InputMode'] = _INPUTMODE
DESCRIPTOR.enum_types_by_name['AlgorithmName'] = _ALGORITHMNAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AlgorithmSpecification = _reflection.GeneratedProtocolMessageType('AlgorithmSpecification', (_message.Message,), dict(

  MetricDefinition = _reflection.GeneratedProtocolMessageType('MetricDefinition', (_message.Message,), dict(
    DESCRIPTOR = _ALGORITHMSPECIFICATION_METRICDEFINITION,
    __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition)
    ))
  ,
  DESCRIPTOR = _ALGORITHMSPECIFICATION,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.AlgorithmSpecification)
  ))
_sym_db.RegisterMessage(AlgorithmSpecification)
_sym_db.RegisterMessage(AlgorithmSpecification.MetricDefinition)

TrainingJobConfig = _reflection.GeneratedProtocolMessageType('TrainingJobConfig', (_message.Message,), dict(
  DESCRIPTOR = _TRAININGJOBCONFIG,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.TrainingJobConfig)
  ))
_sym_db.RegisterMessage(TrainingJobConfig)

StoppingCondition = _reflection.GeneratedProtocolMessageType('StoppingCondition', (_message.Message,), dict(
  DESCRIPTOR = _STOPPINGCONDITION,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.StoppingCondition)
  ))
_sym_db.RegisterMessage(StoppingCondition)

TrainingJob = _reflection.GeneratedProtocolMessageType('TrainingJob', (_message.Message,), dict(
  DESCRIPTOR = _TRAININGJOB,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.TrainingJob)
  ))
_sym_db.RegisterMessage(TrainingJob)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/event/event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/event/event.proto',
  package='flyteidl.event',
  syntax='proto3',
  serialized_options=_b('Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/event'),
  serialized_pb=_b('\n\x1a\x66lyteidl/event/event.proto\x12\x0e\x66lyteidl.event\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xae\x02\n\x16WorkflowExecutionEvent\x12@\n\x0c\x65xecution_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12\x35\n\x05phase\x18\x03 \x01(\x0e\x32&.flyteidl.core.WorkflowExecution.Phase\x12/\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\noutput_uri\x18\x05 \x01(\tH\x00\x12.\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x42\x0f\n\routput_result\"\xd1\x03\n\x12NodeExecutionEvent\x12\x32\n\x02id\x18\x01 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifier\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12\x31\n\x05phase\x18\x03 \x01(\x0e\x32\".flyteidl.core.NodeExecution.Phase\x12/\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tinput_uri\x18\x05 \x01(\t\x12\x14\n\noutput_uri\x18\x06 \x01(\tH\x00\x12.\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x12\x46\n\x16workflow_node_metadata\x18\x08 \x01(\x0b\x32$.flyteidl.event.WorkflowNodeMetadataH\x01\x12I\n\x14parent_task_metadata\x18\t \x01(\x0b\x32+.flyteidl.event.ParentTaskExecutionMetadataB\x0f\n\routput_resultB\x11\n\x0ftarget_metadata\"X\n\x14WorkflowNodeMetadata\x12@\n\x0c\x65xecution_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"Q\n\x1bParentTaskExecutionMetadata\x12\x32\n\x02id\x18\x01 \x01(\x0b\x32&.flyteidl.core.TaskExecutionIdentifier\"\xef\x03\n\x12TaskExecutionEvent\x12*\n\x07task_id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12H\n\x18parent_node_execution_id\x18\x02 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifier\x12\x15\n\rretry_attempt\x18\x03 \x01(\r\x12\x31\n\x05phase\x18\x04 \x01(\x0e\x32\".flyteidl.core.TaskExecution.Phase\x12\x13\n\x0bproducer_id\x18\x05 \x01(\t\x12$\n\x04logs\x18\x06 \x03(\x0b\x32\x16.flyteidl.core.TaskLog\x12/\n\x0boccurred_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tinput_uri\x18\x08 \x01(\t\x12\x14\n\noutput_uri\x18\t \x01(\tH\x00\x12.\n\x05\x65rror\x18\n \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x12,\n\x0b\x63ustom_info\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rphase_version\x18\x0c \x01(\rB\x0f\n\routput_resultB3Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/eventb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_WORKFLOWEXECUTIONEVENT = _descriptor.Descriptor(
  name='WorkflowExecutionEvent',
  full_name='flyteidl.event.WorkflowExecutionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='flyteidl.event.WorkflowExecutionEvent.execution_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='flyteidl.event.WorkflowExecutionEvent.producer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.event.WorkflowExecutionEvent.phase', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occurred_at', full_name='flyteidl.event.WorkflowExecutionEvent.occurred_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_uri', full_name='flyteidl.event.WorkflowExecutionEvent.output_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.event.WorkflowExecutionEvent.error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.event.WorkflowExecutionEvent.output_result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=173,
  serialized_end=475,
)


_NODEEXECUTIONEVENT = _descriptor.Descriptor(
  name='NodeExecutionEvent',
  full_name='flyteidl.event.NodeExecutionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.event.NodeExecutionEvent.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='flyteidl.event.NodeExecutionEvent.producer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.event.NodeExecutionEvent.phase', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occurred_at', full_name='flyteidl.event.NodeExecutionEvent.occurred_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_uri', full_name='flyteidl.event.NodeExecutionEvent.input_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_uri', full_name='flyteidl.event.NodeExecutionEvent.output_uri', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.event.NodeExecutionEvent.error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow_node_metadata', full_name='flyteidl.event.NodeExecutionEvent.workflow_node_metadata', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_task_metadata', full_name='flyteidl.event.NodeExecutionEvent.parent_task_metadata', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.event.NodeExecutionEvent.output_result',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='target_metadata', full_name='flyteidl.event.NodeExecutionEvent.target_metadata',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=478,
  serialized_end=943,
)


_WORKFLOWNODEMETADATA = _descriptor.Descriptor(
  name='WorkflowNodeMetadata',
  full_name='flyteidl.event.WorkflowNodeMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='flyteidl.event.WorkflowNodeMetadata.execution_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1033,
)


_PARENTTASKEXECUTIONMETADATA = _descriptor.Descriptor(
  name='ParentTaskExecutionMetadata',
  full_name='flyteidl.event.ParentTaskExecutionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.event.ParentTaskExecutionMetadata.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1116,
)


_TASKEXECUTIONEVENT = _descriptor.Descriptor(
  name='TaskExecutionEvent',
  full_name='flyteidl.event.TaskExecutionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='flyteidl.event.TaskExecutionEvent.task_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_node_execution_id', full_name='flyteidl.event.TaskExecutionEvent.parent_node_execution_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retry_attempt', full_name='flyteidl.event.TaskExecutionEvent.retry_attempt', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.event.TaskExecutionEvent.phase', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='flyteidl.event.TaskExecutionEvent.producer_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logs', full_name='flyteidl.event.TaskExecutionEvent.logs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occurred_at', full_name='flyteidl.event.TaskExecutionEvent.occurred_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_uri', full_name='flyteidl.event.TaskExecutionEvent.input_uri', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_uri', full_name='flyteidl.event.TaskExecutionEvent.output_uri', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.event.TaskExecutionEvent.error', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_info', full_name='flyteidl.event.TaskExecutionEvent.custom_info', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase_version', full_name='flyteidl.event.TaskExecutionEvent.phase_version', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.event.TaskExecutionEvent.output_result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1119,
  serialized_end=1614,
)

_WORKFLOWEXECUTIONEVENT.fields_by_name['execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONEVENT.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._WORKFLOWEXECUTION_PHASE
_WORKFLOWEXECUTIONEVENT.fields_by_name['occurred_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOWEXECUTIONEVENT.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _WORKFLOWEXECUTIONEVENT.fields_by_name['output_uri'])
_WORKFLOWEXECUTIONEVENT.fields_by_name['output_uri'].containing_oneof = _WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result']
_WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _WORKFLOWEXECUTIONEVENT.fields_by_name['error'])
_WORKFLOWEXECUTIONEVENT.fields_by_name['error'].containing_oneof = _WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result']
_NODEEXECUTIONEVENT.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_NODEEXECUTIONEVENT.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._NODEEXECUTION_PHASE
_NODEEXECUTIONEVENT.fields_by_name['occurred_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODEEXECUTIONEVENT.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_NODEEXECUTIONEVENT.fields_by_name['workflow_node_metadata'].message_type = _WORKFLOWNODEMETADATA
_NODEEXECUTIONEVENT.fields_by_name['parent_task_metadata'].message_type = _PARENTTASKEXECUTIONMETADATA
_NODEEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['output_uri'])
_NODEEXECUTIONEVENT.fields_by_name['output_uri'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['output_result']
_NODEEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['error'])
_NODEEXECUTIONEVENT.fields_by_name['error'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['output_result']
_NODEEXECUTIONEVENT.oneofs_by_name['target_metadata'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['workflow_node_metadata'])
_NODEEXECUTIONEVENT.fields_by_name['workflow_node_metadata'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['target_metadata']
_WORKFLOWNODEMETADATA.fields_by_name['execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_PARENTTASKEXECUTIONMETADATA.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._TASKEXECUTIONIDENTIFIER
_TASKEXECUTIONEVENT.fields_by_name['task_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_TASKEXECUTIONEVENT.fields_by_name['parent_node_execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_TASKEXECUTIONEVENT.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._TASKEXECUTION_PHASE
_TASKEXECUTIONEVENT.fields_by_name['logs'].message_type = flyteidl_dot_core_dot_execution__pb2._TASKLOG
_TASKEXECUTIONEVENT.fields_by_name['occurred_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TASKEXECUTIONEVENT.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_TASKEXECUTIONEVENT.fields_by_name['custom_info'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_TASKEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _TASKEXECUTIONEVENT.fields_by_name['output_uri'])
_TASKEXECUTIONEVENT.fields_by_name['output_uri'].containing_oneof = _TASKEXECUTIONEVENT.oneofs_by_name['output_result']
_TASKEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _TASKEXECUTIONEVENT.fields_by_name['error'])
_TASKEXECUTIONEVENT.fields_by_name['error'].containing_oneof = _TASKEXECUTIONEVENT.oneofs_by_name['output_result']
DESCRIPTOR.message_types_by_name['WorkflowExecutionEvent'] = _WORKFLOWEXECUTIONEVENT
DESCRIPTOR.message_types_by_name['NodeExecutionEvent'] = _NODEEXECUTIONEVENT
DESCRIPTOR.message_types_by_name['WorkflowNodeMetadata'] = _WORKFLOWNODEMETADATA
DESCRIPTOR.message_types_by_name['ParentTaskExecutionMetadata'] = _PARENTTASKEXECUTIONMETADATA
DESCRIPTOR.message_types_by_name['TaskExecutionEvent'] = _TASKEXECUTIONEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkflowExecutionEvent = _reflection.GeneratedProtocolMessageType('WorkflowExecutionEvent', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONEVENT,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.WorkflowExecutionEvent)
  ))
_sym_db.RegisterMessage(WorkflowExecutionEvent)

NodeExecutionEvent = _reflection.GeneratedProtocolMessageType('NodeExecutionEvent', (_message.Message,), dict(
  DESCRIPTOR = _NODEEXECUTIONEVENT,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.NodeExecutionEvent)
  ))
_sym_db.RegisterMessage(NodeExecutionEvent)

WorkflowNodeMetadata = _reflection.GeneratedProtocolMessageType('WorkflowNodeMetadata', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWNODEMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.WorkflowNodeMetadata)
  ))
_sym_db.RegisterMessage(WorkflowNodeMetadata)

ParentTaskExecutionMetadata = _reflection.GeneratedProtocolMessageType('ParentTaskExecutionMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PARENTTASKEXECUTIONMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.ParentTaskExecutionMetadata)
  ))
_sym_db.RegisterMessage(ParentTaskExecutionMetadata)

TaskExecutionEvent = _reflection.GeneratedProtocolMessageType('TaskExecutionEvent', (_message.Message,), dict(
  DESCRIPTOR = _TASKEXECUTIONEVENT,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.TaskExecutionEvent)
  ))
_sym_db.RegisterMessage(TaskExecutionEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/sagemaker/parameter_ranges.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/sagemaker/parameter_ranges.proto',
  package='flyteidl.plugins.sagemaker',
  syntax='proto3',
  serialized_options=_b('Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n1flyteidl/plugins/sagemaker/parameter_ranges.proto\x12\x1a\x66lyteidl.plugins.sagemaker\"\x8d\x01\n\x18\x43ontinuousParameterRange\x12\x11\n\tmax_value\x18\x01 \x01(\x01\x12\x11\n\tmin_value\x18\x02 \x01(\x01\x12K\n\x0cscaling_type\x18\x03 \x01(\x0e\x32\x35.flyteidl.plugins.sagemaker.HyperparameterScalingType\"\x8a\x01\n\x15IntegerParameterRange\x12\x11\n\tmax_value\x18\x01 \x01(\x03\x12\x11\n\tmin_value\x18\x02 \x01(\x03\x12K\n\x0cscaling_type\x18\x03 \x01(\x0e\x32\x35.flyteidl.plugins.sagemaker.HyperparameterScalingType\"+\n\x19\x43\x61tegoricalParameterRange\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xbd\x02\n\x13ParameterRangeOneOf\x12Z\n\x1a\x63ontinuous_parameter_range\x18\x01 \x01(\x0b\x32\x34.flyteidl.plugins.sagemaker.ContinuousParameterRangeH\x00\x12T\n\x17integer_parameter_range\x18\x02 \x01(\x0b\x32\x31.flyteidl.plugins.sagemaker.IntegerParameterRangeH\x00\x12\\\n\x1b\x63\x61tegorical_parameter_range\x18\x03 \x01(\x0b\x32\x35.flyteidl.plugins.sagemaker.CategoricalParameterRangeH\x00\x42\x16\n\x14parameter_range_type\"\xdd\x01\n\x0fParameterRanges\x12_\n\x13parameter_range_map\x18\x01 \x03(\x0b\x32\x42.flyteidl.plugins.sagemaker.ParameterRanges.ParameterRangeMapEntry\x1ai\n\x16ParameterRangeMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.flyteidl.plugins.sagemaker.ParameterRangeOneOf:\x02\x38\x01*Z\n\x19HyperparameterScalingType\x12\x08\n\x04\x41UTO\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\x0f\n\x0bLOGARITHMIC\x10\x02\x12\x16\n\x12REVERSELOGARITHMIC\x10\x03\x42\x35Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)

_HYPERPARAMETERSCALINGTYPE = _descriptor.EnumDescriptor(
  name='HyperparameterScalingType',
  full_name='flyteidl.plugins.sagemaker.HyperparameterScalingType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINEAR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOGARITHMIC', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REVERSELOGARITHMIC', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=955,
  serialized_end=1045,
)
_sym_db.RegisterEnumDescriptor(_HYPERPARAMETERSCALINGTYPE)

HyperparameterScalingType = enum_type_wrapper.EnumTypeWrapper(_HYPERPARAMETERSCALINGTYPE)
AUTO = 0
LINEAR = 1
LOGARITHMIC = 2
REVERSELOGARITHMIC = 3



_CONTINUOUSPARAMETERRANGE = _descriptor.Descriptor(
  name='ContinuousParameterRange',
  full_name='flyteidl.plugins.sagemaker.ContinuousParameterRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_value', full_name='flyteidl.plugins.sagemaker.ContinuousParameterRange.max_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='flyteidl.plugins.sagemaker.ContinuousParameterRange.min_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scaling_type', full_name='flyteidl.plugins.sagemaker.ContinuousParameterRange.scaling_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=223,
)


_INTEGERPARAMETERRANGE = _descriptor.Descriptor(
  name='IntegerParameterRange',
  full_name='flyteidl.plugins.sagemaker.IntegerParameterRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_value', full_name='flyteidl.plugins.sagemaker.IntegerParameterRange.max_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='flyteidl.plugins.sagemaker.IntegerParameterRange.min_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scaling_type', full_name='flyteidl.plugins.sagemaker.IntegerParameterRange.scaling_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=364,
)


_CATEGORICALPARAMETERRANGE = _descriptor.Descriptor(
  name='CategoricalParameterRange',
  full_name='flyteidl.plugins.sagemaker.CategoricalParameterRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='flyteidl.plugins.sagemaker.CategoricalParameterRange.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=409,
)


_PARAMETERRANGEONEOF = _descriptor.Descriptor(
  name='ParameterRangeOneOf',
  full_name='flyteidl.plugins.sagemaker.ParameterRangeOneOf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='continuous_parameter_range', full_name='flyteidl.plugins.sagemaker.ParameterRangeOneOf.continuous_parameter_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_parameter_range', full_name='flyteidl.plugins.sagemaker.ParameterRangeOneOf.integer_parameter_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='categorical_parameter_range', full_name='flyteidl.plugins.sagemaker.ParameterRangeOneOf.categorical_parameter_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parameter_range_type', full_name='flyteidl.plugins.sagemaker.ParameterRangeOneOf.parameter_range_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=412,
  serialized_end=729,
)


_PARAMETERRANGES_PARAMETERRANGEMAPENTRY = _descriptor.Descriptor(
  name='ParameterRangeMapEntry',
  full_name='flyteidl.plugins.sagemaker.ParameterRanges.ParameterRangeMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.plugins.sagemaker.ParameterRanges.ParameterRangeMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.plugins.sagemaker.ParameterRanges.ParameterRangeMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=953,
)

_PARAMETERRANGES = _descriptor.Descriptor(
  name='ParameterRanges',
  full_name='flyteidl.plugins.sagemaker.ParameterRanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter_range_map', full_name='flyteidl.plugins.sagemaker.ParameterRanges.parameter_range_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARAMETERRANGES_PARAMETERRANGEMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=953,
)

_CONTINUOUSPARAMETERRANGE.fields_by_name['scaling_type'].enum_type = _HYPERPARAMETERSCALINGTYPE
_INTEGERPARAMETERRANGE.fields_by_name['scaling_type'].enum_type = _HYPERPARAMETERSCALINGTYPE
_PARAMETERRANGEONEOF.fields_by_name['continuous_parameter_range'].message_type = _CONTINUOUSPARAMETERRANGE
_PARAMETERRANGEONEOF.fields_by_name['integer_parameter_range'].message_type = _INTEGERPARAMETERRANGE
_PARAMETERRANGEONEOF.fields_by_name['categorical_parameter_range'].message_type = _CATEGORICALPARAMETERRANGE
_PARAMETERRANGEONEOF.oneofs_by_name['parameter_range_type'].fields.append(
  _PARAMETERRANGEONEOF.fields_by_name['continuous_parameter_range'])
_PARAMETERRANGEONEOF.fields_by_name['continuous_parameter_range'].containing_oneof = _PARAMETERRANGEONEOF.oneofs_by_name['parameter_range_type']
_PARAMETERRANGEONEOF.oneofs_by_name['parameter_range_type'].fields.append(
  _PARAMETERRANGEONEOF.fields_by_name['integer_parameter_range'])
_PARAMETERRANGEONEOF.fields_by_name['integer_parameter_range'].containing_oneof = _PARAMETERRANGEONEOF.oneofs_by_name['parameter_range_type']
_PARAMETERRANGEONEOF.oneofs_by_name['parameter_range_type'].fields.append(
  _PARAMETERRANGEONEOF.fields_by_name['categorical_parameter_range'])
_PARAMETERRANGEONEOF.fields_by_name['categorical_parameter_range'].containing_oneof = _PARAMETERRANGEONEOF.oneofs_by_name['parameter_range_type']
_PARAMETERRANGES_PARAMETERRANGEMAPENTRY.fields_by_name['value'].message_type = _PARAMETERRANGEONEOF
_PARAMETERRANGES_PARAMETERRANGEMAPENTRY.containing_type = _PARAMETERRANGES
_PARAMETERRANGES.fields_by_name['parameter_range_map'].message_type = _PARAMETERRANGES_PARAMETERRANGEMAPENTRY
DESCRIPTOR.message_types_by_name['ContinuousParameterRange'] = _CONTINUOUSPARAMETERRANGE
DESCRIPTOR.message_types_by_name['IntegerParameterRange'] = _INTEGERPARAMETERRANGE
DESCRIPTOR.message_types_by_name['CategoricalParameterRange'] = _CATEGORICALPARAMETERRANGE
DESCRIPTOR.message_types_by_name['ParameterRangeOneOf'] = _PARAMETERRANGEONEOF
DESCRIPTOR.message_types_by_name['ParameterRanges'] = _PARAMETERRANGES
DESCRIPTOR.enum_types_by_name['HyperparameterScalingType'] = _HYPERPARAMETERSCALINGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ContinuousParameterRange = _reflection.GeneratedProtocolMessageType('ContinuousParameterRange', (_message.Message,), dict(
  DESCRIPTOR = _CONTINUOUSPARAMETERRANGE,
  __module__ = 'flyteidl.plugins.sagemaker.parameter_ranges_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.ContinuousParameterRange)
  ))
_sym_db.RegisterMessage(ContinuousParameterRange)

IntegerParameterRange = _reflection.GeneratedProtocolMessageType('IntegerParameterRange', (_message.Message,), dict(
  DESCRIPTOR = _INTEGERPARAMETERRANGE,
  __module__ = 'flyteidl.plugins.sagemaker.parameter_ranges_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.IntegerParameterRange)
  ))
_sym_db.RegisterMessage(IntegerParameterRange)

CategoricalParameterRange = _reflection.GeneratedProtocolMessageType('CategoricalParameterRange', (_message.Message,), dict(
  DESCRIPTOR = _CATEGORICALPARAMETERRANGE,
  __module__ = 'flyteidl.plugins.sagemaker.parameter_ranges_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.CategoricalParameterRange)
  ))
_sym_db.RegisterMessage(CategoricalParameterRange)

ParameterRangeOneOf = _reflection.GeneratedProtocolMessageType('ParameterRangeOneOf', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETERRANGEONEOF,
  __module__ = 'flyteidl.plugins.sagemaker.parameter_ranges_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.ParameterRangeOneOf)
  ))
_sym_db.RegisterMessage(ParameterRangeOneOf)

ParameterRanges = _reflection.GeneratedProtocolMessageType('ParameterRanges', (_message.Message,), dict(

  ParameterRangeMapEntry = _reflection.GeneratedProtocolMessageType('ParameterRangeMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _PARAMETERRANGES_PARAMETERRANGEMAPENTRY,
    __module__ = 'flyteidl.plugins.sagemaker.parameter_ranges_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.ParameterRanges.ParameterRangeMapEntry)
    ))
  ,
  DESCRIPTOR = _PARAMETERRANGES,
  __module__ = 'flyteidl.plugins.sagemaker.parameter_ranges_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.ParameterRanges)
  ))
_sym_db.RegisterMessage(ParameterRanges)
_sym_db.RegisterMessage(ParameterRanges.ParameterRangeMapEntry)


DESCRIPTOR._options = None
_PARAMETERRANGES_PARAMETERRANGEMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
